@@ -327,8 +327,7 @@ class Region:
 
         # Create an empty mask.
         #
-        mask = ['\x00'] * maskSize
-        return "".join(mask)
+        return '\x00' * maskSize
 
     def repositionCursor(self):
         """Reposition the cursor offset for contracted mode.
@@ -528,8 +527,8 @@ class Text(Region):
         self.accessible = accessible
         if orca_state.activeScript and self.accessible:
             [string, self.caretOffset, self.lineOffset] = \
-                 orca_state.activeScript.getTextLineAtCaret(self.accessible,
-                                                            startOffset)
+                 orca_state.activeScript.getTextLineAtCaret(
+                     self.accessible, startOffset=startOffset, endOffset=endOffset)
         else:
             string = ""
             self.caretOffset = 0
