@@ -324,13 +324,14 @@ class BrailleGenerator(generator.Generator):
         if role not in [pyatspi.ROLE_LIST, pyatspi.ROLE_LIST_BOX]:
             return result
 
-        items = self._script.utilities.selectedChildren(obj)
-        items = items or [self._script.utilities.focusedChild(obj)]
+        if 'Selection' in pyatspi.listInterfaces(obj):
+            items = self._script.utilities.selectedChildren(obj)
+        else:
+            items = items or [self._script.utilities.focusedChild(obj)]
         if not (items and items[0]):
             return result
 
-        items = list(map(self._generateName, items))
-        for item in items:
+        for item in map(self._generateName, items):
             result.extend(item)
 
         return result
