@@ -36,8 +36,6 @@ from . import object_properties
 from . import orca_state
 from . import settings
 
-from .braille_generator import BrailleGenerator
-
 # [[[WDW - HACK Regular expression to split strings on whitespace
 # boundaries, which is what we'll use for word dividers instead of
 # living at the whim of whomever decided to implement the AT-SPI
@@ -137,11 +135,6 @@ class Word:
                     [char, startOffset, endOffset] = text.getTextAtOffset(
                         self.startOffset + i,
                         pyatspi.TEXT_BOUNDARY_CHAR)
-                    # Sometimes we get more than a character's worth. See
-                    # Bug #495303. We can try to correct this.
-                    #
-                    if len(char):
-                        char[0]
                     [x, y, width, height] = text.getRangeExtents(
                         startOffset,
                         startOffset + 1,
@@ -427,7 +420,8 @@ class ValueZone(Zone):
 
             speechValue = speechValue + " " + messages.percentage(percentValue)
 
-            rolename = BrailleGenerator.getLocalizedRoleName(self.accessible)
+            rolename = orca_state.activeScript.brailleGenerator.getLocalizedRoleName(
+                self.accessible)
             if orientation:
                 brailleValue = "%s %s %d%%" % (orientation,
                     rolename,
@@ -655,13 +649,12 @@ class Context:
                 while zoneIndex < len(line.zones):
                     zone = line.zones[zoneIndex]
                     if zone.accessible == accessible:
-                        if (caretOffset >= zone.startOffset):
-                            if (caretOffset \
-                                    < (zone.startOffset + zone.length)):
+                        if caretOffset >= zone.startOffset:
+                            endOffset = zone.startOffset + zone.length
+                            if caretOffset < endOffset:
                                 foundZoneWithCaret = True
                                 break
-                            elif (caretOffset \
-                                    == (zone.startOffset + zone.length)):
+                            elif caretOffset == endOffset:
                                 checkForEOF = True
                                 lineToCheck = lineIndex
                                 zoneToCheck = zoneIndex
