@@ -434,6 +434,11 @@ formatting = {
             'unfocused': 'labelAndName',
             'basicWhereAmI': 'labelAndName'
             },
+        pyatspi.ROLE_TREE_ITEM: {
+            'focused': 'expandableState',
+            'unfocused': '(labelOrName or displayedText) + pause + expandableState + pause + positionInList',
+            'basicWhereAmI': '(labelOrName or displayedText) + roleName + pause + positionInList + pause + expandableState + (nodeLevel or nestingLevel)'
+            },
     },
 
     ####################################################################
@@ -556,7 +561,7 @@ formatting = {
                                      asString(labelAndName + value + roleName + required))]',
             },
         pyatspi.ROLE_LABEL: {
-            'unfocused': '[Text(obj, asString(label))]'
+            'unfocused': '[Text(obj, asString(labelAndName))]'
             },
         pyatspi.ROLE_LINK: {
             'unfocused': '[Link(obj, asString(currentLineText)\
@@ -703,6 +708,11 @@ formatting = {
         pyatspi.ROLE_TOOL_BAR: {
             'unfocused': '[Component(obj, asString(labelOrName + roleName))]',
             },
+        pyatspi.ROLE_TREE_ITEM: {
+            'unfocused': '((substring and ' + BRAILLE_TEXT + ')\
+                          or ([Component(obj, asString(labelOrName + expandableState))]\
+                              + (nestingLevel and [Region(" " + asString(nestingLevel))])))',
+            },
         #pyatspi.ROLE_TREE: 'default'
         #pyatspi.ROLE_TREE_TABLE: 'default'
         #pyatspi.ROLE_WINDOW: 'default'
@@ -829,6 +839,10 @@ formatting = {
             'focused': 'expandableState or toggleState',
             'unfocused': 'roleName + (expandableState or toggleState) + availability',
         },
+        pyatspi.ROLE_TREE_ITEM: {
+            'focused': 'expandableState',
+            'unfocused': 'roleName + expandableState + positionInSet',
+        },
     },
 }
 
@@ -840,7 +854,7 @@ class Formatting(dict):
         self.update(copy.deepcopy(formatting))
 
     def update(self, newDict):
-        for key, val in list(newDict.items()):
+        for key, val in newDict.items():
             if key in self:
                 if isinstance(self[key], dict) and isinstance(val, dict):
                     self[key].update(val)
