@@ -96,7 +96,7 @@ class Generator:
         # for the results of all the legal method names.
         #
         globalsDict = {}
-        for key in list(self._methodsDict.keys()):
+        for key in self._methodsDict.keys():
             globalsDict[key] = []
         self._addGlobals(globalsDict)
 
@@ -308,6 +308,7 @@ class Generator:
                 return result
             if description:
                 result.append(description)
+                self._script.pointOfReference['usedDescriptionForName'] = True
             else:
                 link = None
                 if obj.getRole() == pyatspi.ROLE_LINK:
@@ -373,6 +374,9 @@ class Generator:
         is different from that of the name and label.
         """
 
+        if self._script.pointOfReference.get('usedDescriptionForName'):
+            return []
+
         role = args.get('role', obj.getRole())
 
         # The text in the description is the same as the text in the page
@@ -380,6 +384,12 @@ class Generator:
         if role == pyatspi.ROLE_TERMINAL:
             return []
 
+        # Unity Panel Service menubar items are labels which claim focus and
+        # have an accessible description of the text + underscore symbol used
+        # to create the mnemonic. We'll work around that here for now.
+        if role == pyatspi.ROLE_LABEL:
+            return []
+
         result = []
         if obj.description:
             label = self._script.utilities.displayedLabel(obj) or ""
