@@ -95,7 +95,8 @@ class KeyboardEvent(InputEvent):
         self.keyval_name = ""
         self.is_text = event.is_text
         self.timestamp = event.timestamp
-        self.is_duplicate = self == orca_state.lastInputEvent
+        self.is_duplicate = self in [orca_state.lastInputEvent,
+                                     orca_state.lastNonModifierKeyEvent]
         self._script = orca_state.activeScript
         self._app = None
         self._window = orca_state.activeWindow
@@ -162,7 +163,7 @@ class KeyboardEvent(InputEvent):
         elif self.isLockingKey():
             self.keyType = KeyboardEvent.TYPE_LOCKING
             self.shouldEcho = settings.presentLockingKeys
-            if self.shouldEcho == None:
+            if self.shouldEcho is None:
                 self.shouldEcho = not settings.onlySpeakDisplayedText
             self.shouldEcho = self.shouldEcho and _isPressed
         elif self.isAlphabeticKey():
@@ -444,7 +445,7 @@ class KeyboardEvent(InputEvent):
         include when presenting a locking key."""
 
         locked = self.getLockingState()
-        if locked == None:
+        if locked is None:
             return ''
 
         if not locked:
