@@ -63,7 +63,9 @@ class ScriptManager:
              'marco':            'metacity',
              'Nereid':           'Banshee',
              'vte':              'gnome-terminal',
-             'gnome-terminal-server': 'gnome-terminal'}
+             'gnome-terminal-server': 'gnome-terminal',
+             'mate-notification-daemon': 'notification-daemon',
+            }
 
         self.setActiveScript(None, "__init__")
         self._desktop = pyatspi.Registry.getDesktop(0)
@@ -94,7 +96,7 @@ class ScriptManager:
         """Returns the module name of the script to use for application app."""
 
         try:
-            appAndNameExist = app != None and app.name != ''
+            appAndNameExist = app is not None and app.name != ''
         except (LookupError, RuntimeError):
             appAndNameExist = False
             msg = 'ERROR: %s no longer exists' % app
@@ -282,7 +284,7 @@ class ScriptManager:
 
         appList = list(self.appScripts.keys())
         try:
-            appList = [a for a in appList if a != None and a not in self._desktop]
+            appList = [a for a in appList if a is not None and a not in self._desktop]
         except:
             debug.printException(debug.LEVEL_FINEST)
             return
@@ -296,7 +298,7 @@ class ScriptManager:
             except KeyError:
                 pass
             else:
-                for toolkitScript in list(toolkitScripts.values()):
+                for toolkitScript in toolkitScripts.values():
                     del toolkitScript
 
             del app
