@@ -106,9 +106,15 @@ class Utilities(script_utilities.Utilities):
             return False
 
         parent = obj.parent
-        if parent and parent.getRoleName() == 'text frame':
-            if self.spreadSheetCellName(parent):
-                return True
+        try:
+            role = parent.getRole()
+        except:
+            msg = "SOFFICE: Exception getting role of %s" % parent
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return False
+
+        if role in [pyatspi.ROLE_EXTENDED, pyatspi.ROLE_PANEL]:
+            return self.spreadSheetCellName(parent)
 
         return False
 
@@ -235,8 +241,8 @@ class Utilities(script_utilities.Utilities):
         if headersRow == objRow or headersCol == objCol:
             return None, None
 
-        getRowHeader = headersCol != None
-        getColHeader = headersRow != None
+        getRowHeader = headersCol is not None
+        getColHeader = headersRow is not None
         if onlyIfNew:
             getRowHeader = \
                 getRowHeader and objRow != self._script.pointOfReference.get("lastRow")
@@ -297,6 +303,37 @@ class Utilities(script_utilities.Utilities):
 
         return script_utilities.Utilities.isLayoutOnly(self, obj)
 
+    def isAnInputLine(self, obj):
+        if not obj:
+            return False
+        if obj == self.locateInputLine(obj):
+            return True
+
+        parent = obj.parent
+        try:
+            role = parent.getRole()
+        except:
+            msg = "SOFFICE: Exception getting role of %s" % parent
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return False
+
+        if role in [pyatspi.ROLE_EXTENDED, pyatspi.ROLE_PANEL]:
+            if self.spreadSheetCellName(parent):
+                return False
+
+        parent = parent.parent
+        try:
+            role = parent.getRole()
+        except:
+            msg = "SOFFICE: Exception getting role of %s" % parent
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return False
+
+        if role == pyatspi.ROLE_TEXT:
+            return True
+
+        return False
+
     def locateInputLine(self, obj):
         """Return the spread sheet input line. This only needs to be found
         the very first time a spread sheet table cell gets focus. We use the
@@ -312,7 +349,15 @@ class Utilities(script_utilities.Utilities):
         """
 
         if self._script.inputLineForCell:
-            return self._script.inputLineForCell
+            try:
+                topLevel = self.topLevelObject(self._script.inputLineForCell)
+            except:
+                msg = "ERROR: Exception getting topLevelObject for inputline"
+                debug.println(debug.LEVEL_INFO, msg, True)
+                self._script.inputLineForCell = None
+            else:
+                if self.isSameObject(orca_state.activeWindow, topLevel):
+                    return self._script.inputLineForCell
 
         isScrollPane = lambda x: x and x.getRole() == pyatspi.ROLE_SCROLL_PANE
         scrollPane = pyatspi.findAncestor(obj, isScrollPane)
@@ -328,7 +373,7 @@ class Utilities(script_utilities.Utilities):
         if not toolbar:
             msg = "ERROR: Calc inputline toolbar not found."
             debug.println(debug.LEVEL_INFO, msg, True)
-            return
+            return None
 
         isParagraph = lambda x: x and x.getRole() == pyatspi.ROLE_PARAGRAPH
         allParagraphs = pyatspi.findAllDescendants(toolbar, isParagraph)
@@ -479,9 +524,19 @@ class Utilities(script_utilities.Utilities):
         # that the Frame name will end with "Impress", unlocalized.
         #
         if obj:
-            topLevel = self.topLevelObject(obj)
-            if topLevel and not self.isZombie(topLevel) \
-               and topLevel.name.endswith("Impress"):
+            try:
+                topLevel = self.topLevelObject(obj)
+            except:
+                msg = "ERROR: Exception getting top-level object for %s" % obj
+                debug.println(debug.LEVEL_INFO, msg, True)
+                return False
+            if not topLevel:
+                return False
+            if self.isDead(topLevel):
+                msg = "SOFFICE: Top level object %s is dead." % topLevel
+                debug.println(debug.LEVEL_INFO, msg, True)
+                return False
+            if topLevel.name.endswith("Impress"):
                 return True
 
         return False
