@@ -73,7 +73,7 @@ class BrailleGenerator(braille_generator.BrailleGenerator):
                                  pyatspi.ROLE_TABLE_CELL,
                                  pyatspi.ROLE_PANEL])
 
-        if args.get('startOffset') != None and args.get('endOffset') != None:
+        if args.get('startOffset') is not None and args.get('endOffset') is not None:
             doNotDisplay.append(pyatspi.ROLE_ALERT)
 
         result = []
@@ -117,6 +117,16 @@ class BrailleGenerator(braille_generator.BrailleGenerator):
 
         return super()._generateLabel(obj, **args)
 
+    def _generateLabelAndName(self, obj, **args):
+        if self._script.utilities.isTextBlockElement(obj):
+            return []
+
+        role = args.get('role', obj.getRole())
+        if role == pyatspi.ROLE_LABEL and 'Text' in pyatspi.listInterfaces(obj):
+            return []
+
+        return super()._generateLabelAndName(obj, **args)
+
     def _generateExpandedEOCs(self, obj, **args):
         """Returns the expanded embedded object characters for an object."""
         result = []
