@@ -1221,6 +1221,9 @@ class SpeechGenerator(generator.Generator):
         - obj: the text object.
         """
 
+        if not _settingsManager.getSetting('enableSpeechIndentation'):
+            return []
+
         line, caretOffset, startOffset = self._script.getTextLineAtCaret(obj)
         description = self._script.utilities.indentationDescription(line)
         if not description:
@@ -1399,8 +1402,7 @@ class SpeechGenerator(generator.Generator):
         if not (items and items[0]):
             return result
 
-        items = list(map(self._generateName, items))
-        for item in items:
+        for item in map(self._generateName, items):
             result.extend(item)
 
         return result
@@ -1498,18 +1500,29 @@ class SpeechGenerator(generator.Generator):
         commonAncestor = self._script.utilities.commonAncestor(priorObj, obj)
         try:
             role = commonAncestor.getRole()
+            name = commonAncestor.name
         except:
-            pass
+            role = None
+            name = None
         else:
             if role == pyatspi.ROLE_COMBO_BOX:
                 return []
 
+        def _isCommonAncestor(x):
+            if not (name and role):
+                return False
+            return x and x.getRole() == role and x.name == name
+
         skipRoles = args.get('skipRoles', [])
+        skipRoles.append(pyatspi.ROLE_TREE_ITEM)
         stopAtRoles = args.get('stopAtRoles', [])
         stopAtRoles.append(pyatspi.ROLE_APPLICATION)
         if obj != commonAncestor:
             parent = obj.parent
             while parent and not parent in [commonAncestor, parent.parent]:
+                if _isCommonAncestor(parent):
+                    break
+
                 parentRole = parent.getRole()
                 if parentRole in stopAtRoles:
                     break
