@@ -63,7 +63,7 @@ else:
         _speechd_version_ok = True
 
 PUNCTUATION = re.compile('[^\w\s]', re.UNICODE)
-ELLIPSIS = re.compile('(\342\200\246|\.\.\.\s*)')
+ELLIPSIS = re.compile('(\342\200\246|(?<!\.)\.{3,4}(?=(\s|\Z)))')
 
 class SpeechServer(speechserver.SpeechServer):
     # See the parent class for documentation.
@@ -73,10 +73,11 @@ class SpeechServer(speechserver.SpeechServer):
     DEFAULT_SERVER_ID = 'default'
     _SERVER_NAMES = {DEFAULT_SERVER_ID: guilabels.DEFAULT_SYNTHESIZER}
 
+    @staticmethod
     def getFactoryName():
         return guilabels.SPEECH_DISPATCHER
-    getFactoryName = staticmethod(getFactoryName)
 
+    @staticmethod
     def getSpeechServers():
         servers = []
         default = SpeechServer._getSpeechServer(SpeechServer.DEFAULT_SERVER_ID)
@@ -85,8 +86,8 @@ class SpeechServer(speechserver.SpeechServer):
             for module in default.list_output_modules():
                 servers.append(SpeechServer._getSpeechServer(module))
         return servers
-    getSpeechServers = staticmethod(getSpeechServers)
 
+    @classmethod
     def _getSpeechServer(cls, serverId):
         """Return an active server for given id.
 
@@ -99,20 +100,17 @@ class SpeechServer(speechserver.SpeechServer):
         # Don't return the instance, unless it is succesfully added
         # to `_active_Servers'.
         return cls._active_servers.get(serverId)
-    _getSpeechServer = classmethod(_getSpeechServer)
 
+    @staticmethod
     def getSpeechServer(info=None):
-        if info is not None:
-            thisId = info[1]
-        else:
-            thisId = SpeechServer.DEFAULT_SERVER_ID
+        thisId = info[1] if info is not None else SpeechServer.DEFAULT_SERVER_ID
         return SpeechServer._getSpeechServer(thisId)
-    getSpeechServer = staticmethod(getSpeechServer)
 
+    @staticmethod
     def shutdownActiveServers():
-        for server in list(SpeechServer._active_servers.values()):
+        servers = [s for s in SpeechServer._active_servers.values()]
+        for server in servers:
             server.shutdown()
-    shutdownActiveServers = staticmethod(shutdownActiveServers)
 
     # *** Instance methods ***
 
@@ -128,12 +126,12 @@ class SpeechServer(speechserver.SpeechServer):
             (ACSS.FAMILY, self._set_family),
             )
         if not _speechd_available:
-            debug.println(debug.LEVEL_WARNING,
-                          "Speech Dispatcher interface not installed.")
+            msg = 'ERROR: Speech Dispatcher is not available'
+            debug.println(debug.LEVEL_WARNING, msg, True)
             return
         if not _speechd_version_ok:
-            debug.println(debug.LEVEL_WARNING,
-                        "Speech Dispatcher version 0.6.2 or later is required.")
+            msg = 'ERROR: Speech Dispatcher version 0.6.2 or later is required.'
+            debug.println(debug.LEVEL_WARNING, msg, True)
             return
         # The following constants must be initialized in runtime since they
         # depend on the speechd module being available.
@@ -155,9 +153,9 @@ class SpeechServer(speechserver.SpeechServer):
         try:
             self._init()
         except:
-            debug.println(debug.LEVEL_WARNING,
-                          "Speech Dispatcher service failed to connect:")
             debug.printException(debug.LEVEL_WARNING)
+            msg = 'ERROR: Speech Dispatcher service failed to connect'
+            debug.println(debug.LEVEL_WARNING, msg, True)
         else:
             SpeechServer._active_servers[serverId] = self
 
@@ -174,7 +172,14 @@ class SpeechServer(speechserver.SpeechServer):
 
     def updateCapitalizationStyle(self):
         """Updates the capitalization style used by the speech server."""
-        self._client.set_cap_let_recogn(settings.capitalizationStyle)
+
+        if settings.capitalizationStyle == settings.CAPITALIZATION_STYLE_ICON:
+            style = 'icon'
+        elif settings.capitalizationStyle == settings.CAPITALIZATION_STYLE_SPELL:
+            style = 'spell'
+        else:
+            style = 'none'
+        self._client.set_cap_let_recogn(style)
 
     def updatePunctuationLevel(self):
         """ Punctuation level changed, inform this speechServer. """
@@ -186,9 +191,8 @@ class SpeechServer(speechserver.SpeechServer):
             try:
                 return command(*args, **kwargs)
             except speechd.SSIPCommunicationError:
-                debug.println(debug.LEVEL_CONFIGURATION,
-                              "Speech Dispatcher connection lost. "
-                              "Trying to reconnect.")
+                msg = "SPEECH DISPATCHER: Connection lost. Trying to reconnect."
+                debug.println(debug.LEVEL_INFO, msg, True)
                 self.reset()
                 return command(*args, **kwargs)
             except:
@@ -227,7 +231,28 @@ class SpeechServer(speechserver.SpeechServer):
             name = acss_family.get(speechserver.VoiceFamily.NAME)
             if name != self._default_voice_name:
                 self._send_command(set_synthesis_voice, name)
-            
+
+    def _debug_sd_values(self, prefix=""):
+        if debug.debugLevel > debug.LEVEL_INFO:
+            return
+
+        try:
+            sd_rate = self._send_command(self._client.get_rate)
+            sd_pitch = self._send_command(self._client.get_pitch)
+        except:
+            sd_rate = "(exception occurred)"
+            sd_pitch = "(exception occurred)"
+
+        current = self._current_voice_properties
+        msg = "SPEECH DISPATCHER: %sOrca rate %s, pitch %s; " \
+              "SD rate %s, pitch %s" % \
+              (prefix,
+               self._current_voice_properties.get(ACSS.RATE),
+               self._current_voice_properties.get(ACSS.AVERAGE_PITCH),
+               sd_rate,
+               sd_pitch)
+        debug.println(debug.LEVEL_INFO, msg, True)
+
     def _apply_acss(self, acss):
         if acss is None:
             acss = settings.voices[settings.DEFAULT_VOICE]
@@ -305,6 +330,7 @@ class SpeechServer(speechserver.SpeechServer):
         text = text.replace('\n.', '\n')
 
         self._apply_acss(acss)
+        self._debug_sd_values("Speaking '%s' " % text)
         self._send_command(self._client.speak, text, **kwargs)
 
     def _say_all(self, iterator, orca_callback):
@@ -348,9 +374,8 @@ class SpeechServer(speechserver.SpeechServer):
         except KeyError:
             rate = 50
         acss[ACSS.RATE] = max(0, min(99, rate + delta))
-        debug.println(debug.LEVEL_CONFIGURATION,
-                      "Speech rate is now %d" % rate)
-
+        msg = 'SPEECH DISPATCHER: Rate set to %d' % rate
+        debug.println(debug.LEVEL_INFO, msg, True)
         self.speak(decrease and messages.SPEECH_SLOWER \
                    or messages.SPEECH_FASTER, acss=acss)
 
@@ -362,9 +387,8 @@ class SpeechServer(speechserver.SpeechServer):
         except KeyError:
             pitch = 5
         acss[ACSS.AVERAGE_PITCH] = max(0, min(9, pitch + delta))
-        debug.println(debug.LEVEL_CONFIGURATION,
-                      "Speech pitch is now %d" % pitch)
-
+        msg = 'SPEECH DISPATCHER: Pitch set to %d' % pitch
+        debug.println(debug.LEVEL_INFO, msg, True)
         self.speak(decrease and messages.SPEECH_LOWER \
                    or messages.SPEECH_HIGHER, acss=acss)
 
@@ -376,9 +400,8 @@ class SpeechServer(speechserver.SpeechServer):
         except KeyError:
             volume = 5
         acss[ACSS.GAIN] = max(0, min(9, volume + delta))
-        debug.println(debug.LEVEL_CONFIGURATION,
-                      "Speech volume is now %d" % volume)
-
+        msg = 'SPEECH DISPATCHER: Volume set to %d' % volume
+        debug.println(debug.LEVEL_INFO, msg, True)
         self.speak(decrease and messages.SPEECH_SOFTER \
                    or messages.SPEECH_LOUDER, acss=acss)
 
