@@ -30,22 +30,13 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import logging
-from . import settings
-from . import orca_state
-
-log = logging.getLogger("speech")
-
-from . import debug
-
-from .acss import ACSS
-
 class VoiceFamily(dict):
     """Holds the family description for a voice."""
 
     NAME   = "name"
     GENDER = "gender"
     LOCALE = "locale"
+    DIALECT = "dialect"
 
     MALE   = "male"
     FEMALE = "female"
@@ -53,7 +44,8 @@ class VoiceFamily(dict):
     settings = {
         NAME   : None,
         GENDER : None,
-        LOCALE : None
+        LOCALE : None,
+        DIALECT: None,
     }
 
     def __init__(self, props):
@@ -93,15 +85,14 @@ class SayAllContext:
 
 
 class SpeechServer(object):
-
     """Provides speech server abstraction."""
 
+    @staticmethod
     def getFactoryName():
         """Returns a localized name describing this factory."""
         pass
 
-    getFactoryName = staticmethod(getFactoryName)
-
+    @staticmethod
     def getSpeechServers():
         """Gets available speech servers as a list.  The caller
         is responsible for calling the shutdown() method of each
@@ -109,23 +100,19 @@ class SpeechServer(object):
         """
         pass
 
-    getSpeechServers = staticmethod(getSpeechServers)
-
+    @staticmethod
     def getSpeechServer(info):
         """Gets a given SpeechServer based upon the info.
         See SpeechServer.getInfo() for more info.
         """
         pass
 
-    getSpeechServer = staticmethod(getSpeechServer)
-
+    @staticmethod
     def shutdownActiveServers():
         """Cleans up and shuts down this factory.
         """
         pass
 
-    shutdownActiveServers = staticmethod(shutdownActiveServers)
-
     def __init__(self):
         pass
 
@@ -139,35 +126,6 @@ class SpeechServer(object):
         voice families known by the speech server."""
         pass
 
-    def queueText(self, text="", acss=None):
-        """Adds the text to the queue.
-
-        Arguments:
-        - text: text to be spoken
-        - acss: acss.ACSS instance; if None,
-                the default voice settings will be used.
-                Otherwise, the acss settings will be
-                used to augment/override the default
-                voice settings.
-
-        Output is produced by the next call to speak.
-        """
-        pass
-
-    def queueTone(self, pitch=440, duration=50):
-        """Adds a tone to the queue.
-
-        Output is produced by the next call to speak.
-        """
-        pass
-
-    def queueSilence(self, duration=50):
-        """Adds silence to the queue.
-
-        Output is produced by the next call to speak.
-        """
-        pass
-
     def speakCharacter(self, character, acss=None):
         """Speaks a single character immediately.
 
@@ -187,24 +145,7 @@ class SpeechServer(object):
         Arguments:
         - event: the input_event.KeyboardEvent.
         """
-        if event.isPrintableKey() and event.event_string.isupper():
-            voice = ACSS(settings.voices[settings.UPPERCASE_VOICE])
-        else:
-            voice = ACSS(settings.voices[settings.DEFAULT_VOICE])
-
-        event_string = event.getKeyName()
-        if orca_state.activeScript and orca_state.usePronunciationDictionary:
-            event_string = orca_state.activeScript.\
-                utilities.adjustForPronunciation(event_string)
-
-        lockingStateString = event.getLockingStateString()
-        event_string = "%s %s" % (event_string, lockingStateString)
-
-        logLine = "SPEECH OUTPUT: '" + event_string +"'"
-        debug.println(debug.LEVEL_INFO, logLine)
-        log.info(logLine)
-
-        self.speak(event_string, acss=voice)
+        pass
 
     def speakUtterances(self, utteranceList, acss=None, interrupt=True):
         """Speaks the given list of utterances immediately.
@@ -254,11 +195,7 @@ class SpeechServer(object):
                              type is one of PROGRESS, INTERRUPTED, or
                              COMPLETED.
         """
-        for [context, acss] in utteranceIterator:
-            logLine = "SPEECH OUTPUT: '" + context.utterance + "'"
-            debug.println(debug.LEVEL_INFO, logLine)
-            log.info(logLine)
-            self.speak(context.utterance, acss)
+        pass
 
     def increaseSpeechRate(self, step=5):
         """Increases the speech rate.
